@@ -254,6 +254,7 @@ get_identity_sync (GoaOAuthProvider  *provider,
     }
 
  out:
+  g_clear_object (&parser);
   g_clear_error (&identity_error);
   g_clear_object (&call);
   g_clear_object (&proxy);
@@ -338,6 +339,7 @@ build_object (GoaProvider         *provider,
   gboolean photos_enabled;
   gboolean ret;
 
+  account = NULL;
   photos = NULL;
   ret = FALSE;
 
