@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2012, 2013 Red Hat, Inc.
+ * Copyright (C) 2012, 2013, 2015 Red Hat, Inc.
  * Copyright (C) 2013 Intel Corporation
  *
  * This library is free software; you can redistribute it and/or
@@ -192,15 +192,6 @@ out:
   return tp_account;
 }
 
-static void
-set_action_area_spacing (GtkDialog *dialog)
-{
-  GtkWidget *action_area;
-
-  action_area = gtk_dialog_get_action_area (dialog);
-  g_object_set (action_area, "margin-top", 12, NULL);
-}
-
 /* ---------------------------------------------------------------------------------------------------- */
 
 static const gchar *
@@ -416,9 +407,6 @@ add_account (GoaProvider  *provider,
   GoaTelepathyProviderPrivate *priv = GOA_TELEPATHY_PROVIDER (provider)->priv;
   AddAccountData data;
   TpawAccountSettings *settings = NULL;
-  GtkWidget *action_area = NULL;
-  GList *children = NULL;
-  GList *l = NULL;
   TpawAccountWidget *account_widget = NULL;
   GtkRequisition req;
   gint response;
@@ -447,18 +435,8 @@ add_account (GoaProvider  *provider,
   goa_client_new (data.cancellable, goa_client_new_cb, &data);
   wait_for_account_settings_ready (settings, data.loop);
 
-  action_area = gtk_dialog_get_action_area (dialog);
-  /* Remove the default button. */
-  children = gtk_container_get_children (GTK_CONTAINER (action_area));
-  for (l = children; l != NULL; l = l->next)
-    {
-      GtkWidget *child = l->data;
-      gtk_container_remove (GTK_CONTAINER (action_area), child);
-    }
-  g_list_free (children);
-
   account_widget = tpaw_account_widget_new_for_protocol (settings,
-      GTK_BOX (action_area), FALSE);
+      dialog, TRUE);
   gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (account_widget), FALSE, FALSE, 0);
   gtk_widget_show (GTK_WIDGET (account_widget));
   g_signal_connect (account_widget, "account-created",
@@ -466,8 +444,6 @@ add_account (GoaProvider  *provider,
   g_signal_connect (account_widget, "close",
       G_CALLBACK (account_widget_close_cb), &data);
 
-  set_action_area_spacing (dialog);
-
   /* The dialog now contains a lot of empty space between the account widget
    * and the buttons. We force it's vertical size to be just right to fit the
    * widget. */
@@ -558,14 +534,14 @@ edit_connection_parameters (GoaObject  *goa_object,
 
   dialog = gtk_dialog_new_with_buttons (_("Connection Settings"),
       parent,
-      GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+      GTK_DIALOG_MODAL
+      | GTK_DIALOG_DESTROY_WITH_PARENT
+      | GTK_DIALOG_USE_HEADER_BAR,
       NULL, NULL);
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-  set_action_area_spacing (GTK_DIALOG (dialog));
 
   account_widget = tpaw_account_widget_new_for_protocol (settings,
-      GTK_BOX (gtk_dialog_get_action_area (GTK_DIALOG (dialog))),
-      FALSE);
+      GTK_DIALOG (dialog), FALSE);
   g_signal_connect (account_widget, "cancelled",
       G_CALLBACK (account_dialog_widget_cancelled_cb), &error);
   g_signal_connect_swapped (account_widget, "close",
@@ -667,12 +643,13 @@ edit_personal_details (GoaObject  *goa_object,
 
   dialog = gtk_dialog_new_with_buttons (_("Personal Details"),
       parent,
-      GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+      GTK_DIALOG_MODAL
+      | GTK_DIALOG_DESTROY_WITH_PARENT
+      | GTK_DIALOG_USE_HEADER_BAR,
       _("_Cancel"), GTK_RESPONSE_CANCEL,
       _("_OK"), GTK_RESPONSE_OK,
       NULL);
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-  set_action_area_spacing (GTK_DIALOG (dialog));
 
   user_info = tpaw_user_info_new (tp_account);
   gtk_widget_show (user_info);
@@ -875,6 +852,7 @@ edit_parameters_clicked_cb (GtkButton *button,
 
   if (!edit_connection_parameters (data->object, data->parent, &error))
     maybe_show_error (data->parent, error, _("Cannot save the connection parameters"));
+  g_clear_error (&error);
 }
 
 static void
@@ -887,6 +865,7 @@ edit_personal_details_clicked_cb (GtkButton *button,
   if (!edit_personal_details (data->object, data->parent, &error))
     maybe_show_error (data->parent, error,
         _("Cannot save your personal information on the server"));
+  g_clear_error (&error);
 }
 
 static void
@@ -1031,7 +1010,7 @@ goa_telepathy_provider_constructed (GObject *object)
     }
 
   priv->provider_type = g_strdup_printf ("%s/%s",
-      GOA_TELEPATHY_PROVIDER_BASE_TYPE, priv->protocol_name);
+      GOA_TELEPATHY_NAME, priv->protocol_name);
 }
 
 static void
